@@ -1,5 +1,6 @@
 import os
 import json
+import socket
 
 os.path.expanduser('~')
 
@@ -30,6 +31,8 @@ def parse_internet_type(type):
         return 'IPv4'
     elif type in ['6', 'ipv6', 'IPV6', 'IPv6', 'v6', 'Ipv6']:
         return 'IPv6'
+    elif type.upper() in ['A', 'ALL']:
+        return 'All'
     return type
 
 def parse_action_type(**kwargs):
@@ -47,4 +50,22 @@ def parse_action_type(**kwargs):
     elif keep_alive:
         return 'keep_alive'
     
-    return 'login'
\ No newline at end of file
+    return 'login'
+
+# 获取本机IPv4地址
+def my_ip():
+    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    try:
+        s.connect(('192.0.0.8', 1027))
+    except socket.error:
+        return None
+    return s.getsockname()[0]
+
+# 获取本机IPv6地址
+def my_ipv6():
+    s = socket.socket(socket.AF_INET6, socket.SOCK_DGRAM)
+    try:
+        s.connect(('2001:db8::', 1027))
+    except socket.error:
+        return None
+    return s.getsockname()[0]
\ No newline at end of file
